# Generated by Django 3.1.3 on 2020-11-17 15:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sso_auth', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='OauthUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('identifier', models.CharField(max_length=40, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.DeleteModel(
            name='User',
        ),
    ]
